{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# ExportCollection\n",
    "\n",
    "This class will export a collection from the `collections` folder on harbor:10002 to a `.tar.gz` file. A datapackage file is created before compression. Additionally, if the public collection has a `json` folder, it will be turned into a zip file, and that zip file will be referenced in the data package's resources. When the archive is extracted, it will have to be unzipped separately to restore the collection. This will create a rather large `.tar.gz` file (2GB or more in many cases), which may cause upload problems. This should be investigated. We may need to use [pyzenodo3](https://github.com/space-physics/pyzenodo3)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "!pip install datapackage"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Python imports\n",
    "import datetime\n",
    "import glob\n",
    "import os\n",
    "import re\n",
    "import shutil\n",
    "import subprocess\n",
    "from datapackage import DataPackageException, Package\n",
    "\n",
    "# Export class\n",
    "class ExportCollection:\n",
    "    \"\"\"Export a public collection.\"\"\"\n",
    "\n",
    "    def __init__(self, collection, options, base_dir='/home/jovyan/view/collections'):\n",
    "        \"\"\"Initialise.\"\"\"\n",
    "        self.collection = collection\n",
    "        self.options = options\n",
    "        self.base_dir = base_dir\n",
    "        self.collection_dir = f'{base_dir}/{collection}'\n",
    "        self.index_file = self.get_index_file()\n",
    "        self.resources = []\n",
    "        self.package = self.package()\n",
    "        self.fix_index()\n",
    "\n",
    "    def get_index_file(self):\n",
    "        \"\"\"Get the index file.\"\"\"\n",
    "        with open (f'{self.collection_dir}/index.html', 'r') as f:\n",
    "            return f.read()\n",
    "\n",
    "    def infer_resources(self):\n",
    "        \"\"\"Infer resources from the collection directory.\"\"\"\n",
    "        self.package.descriptor['resources'] = []\n",
    "        self.package.add_resource({'path': 'index.html', 'format': 'html', 'profile': 'data-resource'})\n",
    "        paths = glob.glob(f'{self.collection_dir}/**/*', recursive=True)\n",
    "        dirs = [x for x in paths if os.path.isdir(x) and x != f'{self.collection_dir}/project_data/json']\n",
    "        for dir in dirs:\n",
    "            print(f'Collecting resources from {dir}...')\n",
    "            # If this is the project_data folder, add a resource for the json.zip file\n",
    "            if dir == f'{self.collection_dir}/project_data':\n",
    "                self.package.add_resource({'path': 'project_data/json.zip', 'format': 'zip'})\n",
    "            else:\n",
    "                # Do the rest of the directory\n",
    "                filelist = glob.glob(f'{dir}/**/*', recursive=True)\n",
    "                filelist = [x for x in filelist if not os.path.isdir(x)]\n",
    "                if len(filelist) > 0:\n",
    "                    for file in filelist:\n",
    "                        try:\n",
    "                            self.package.add_resource({'path': file.replace(f'{self.collection_dir}/', '')})\n",
    "                        except DataPackageException:\n",
    "                            print(f'Warning! Could not infer `{file}`.')\n",
    "        self.package.commit()\n",
    "\n",
    "    def package(self):\n",
    "        \"\"\"Make a datapackage for the collection.\"\"\"\n",
    "        pk = Package()\n",
    "        for k, v in self.options.items():\n",
    "            pk.descriptor[k] = v\n",
    "        pk.commit()\n",
    "        return pk\n",
    "\n",
    "    def save(self, save_path=None):\n",
    "        \"\"\"Save the collection folder as a .tar.gz archive.\n",
    "        \n",
    "        If there is a json folder, it is zipped first.\n",
    "        \"\"\"\n",
    "        print('Saving data package...')\n",
    "        if not save_path:\n",
    "            save_path = self.base_dir\n",
    "        self.package.save(f'{self.collection_dir}/datapackage.json')\n",
    "        print('Saving archive...')\n",
    "        json_dir = f'{self.collection_dir}/project_data/json'\n",
    "        # Bye bye .ipynb_checkpoints\n",
    "        ipy = list(glob.glob(f'{collection}/**/.ipynb_checkpoints', recursive=True))\n",
    "        for item in ipy:\n",
    "            shutil.rmtree(item)\n",
    "        if os.path.isdir(json_dir):\n",
    "            tmp_dir = f'{self.base_dir}/tmp_{self.collection}_json'\n",
    "            json_zip = f'{self.collection_dir}/project_data/json.zip'\n",
    "            # Move the json folder to a temporary location\n",
    "            print('Making temporary json folder...')\n",
    "            shutil.move(json_dir, tmp_dir)\n",
    "            # Create a zip archive of the temporary folder in the project_data folder\n",
    "            print('Zipping json folder...')\n",
    "            subprocess.call(['zip', '-r', json_zip, tmp_dir])\n",
    "            # Create a tar.gz of the collection folder in exports\n",
    "            print('Creating .tar.gz...')\n",
    "            subprocess.call(['tar', '-cjf', f'{self.collection}.tar.gz', '-C', self.collection_dir, '.'])\n",
    "            # Remove the zip archive from the project_data folder\n",
    "            print('Removing zip archive...')\n",
    "            os.remove(json_zip)\n",
    "            # Copy the temporary folder back to the project_data folder\n",
    "            print('Restoring json folder...')\n",
    "            shutil.move(tmp_dir, json_dir)\n",
    "        else:\n",
    "            subprocess.call(['tar', '-cjf', f'{self.collection}.tar.gz', '-C', self.collection_dir, '.'])\n",
    "        # Restore the harbor 10002 folder\n",
    "        shutil.rmtree(f'{self.collection_dir}/assets')\n",
    "        with open(f'{self.collection_dir}/index.html', 'w') as f:\n",
    "            f.write(self.index_file)\n",
    "        print(f'Archive saved to `{self.base_dir}/{self.collection}.tar.gz`.')\n",
    "\n",
    "    def fix_index(self):\n",
    "        \"\"\"Fix the index file for export.\"\"\"\n",
    "        doc = self.index_file\n",
    "        doc = re.sub('\\<\\!-- Development --\\>', '', doc)\n",
    "        doc = re.sub('<h2>WE1S Developers Only<\\/h2>', '', doc)\n",
    "        doc = re.sub('<a href=\\\".+?\\\" target=\\\"_blank\\\">Project production folder</a> \\(login required\\)', '', doc)\n",
    "        doc = re.sub('<li>\\n\\s+</li>', '', doc)\n",
    "        doc = re.sub('<ul>\\n\\s+</ul>', '', doc)\n",
    "        doc = re.sub('<div id=\\\"development\\\">\\n\\s+</div>\\n', '', doc)\n",
    "        doc = re.sub('integrity=\\\"sha256-pasqAKBDmFT4eHoN2ndd6lN370kFiGUFyTiUHWhU7k8=\\\"', '', doc)\n",
    "        doc = re.sub('crossorigin=\\\"anonymous\\\"><\\/script>', '', doc)\n",
    "        doc = re.sub('\\\"https://code.jquery.com/jquery-3.4.1.slim.min.js\\\"', '\"assets/jquery-3.4.1.slim.min.js\"></script>', doc)\n",
    "        doc = doc.replace('../assets/', 'assets/')\n",
    "        doc = doc.replace('href=\"../\">Other WE1S Collections', 'href=\"https://we1s.ucsb.edu/research/we1s-materials/collections-topic-models/\">Other WE1S Collections')\n",
    "        with open (f'{self.collection_dir}/index.html', 'w') as f:\n",
    "            f.write(doc)\n",
    "        # Move the assets folder\n",
    "        shutil.copytree('/home/jovyan/view/collections/assets', f'/home/jovyan/view/collections/{self.collection}/assets')\n",
    "        os.remove(f'/home/jovyan/view/collections/{self.collection}/assets/index-template.html')\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 114,
   "metadata": {},
   "outputs": [],
   "source": [
    "# shutil.rmtree('/home/jovyan/view/collections/test_zenodo/assets')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Configuration\n",
    "\n",
    "Before exporting, make sure that the configuration below aligns with the information in the collection's `index.html` file. The data package `publication_date` is the collection's creation date in `index.html`. This should align with the `publication_date` in the Zenodo metadata file."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Config\n",
    "collection  = '20200714_2157_reddit-students-and-the-humanities'\n",
    "save_path   = '/home/jovyan/view/export/collections'\n",
    "options     = {\n",
    "  \"name\": collection,\n",
    "  \"title\": \"Collection 39: Reddit on the Humanities\",\n",
    "  \"contributors\": [{\n",
    "    \"title\": \"WhatEvery1Says (WE1S) Project\",\n",
    "    \"path\": \"https://we1s.ucsb.edu\"\n",
    "  }],\n",
    "  \"description\": \"Collection 39 (C-39) is a subset of WE1S’s C-38 Reddit collection tailored to focus on student discourse about the humanities. Where C-38 includes Reddit comments longer than 225 words from 2006 to 2019 containing the terms _humanities_, _liberal arts_, or _the arts_, C-39 consists of 66,290 comments from that larger collection (about half the original number) that also contain at least one of the terms student, major, or college (including plurals and other forms). (Similar to C-38 is WE1S’s Corpus-A, an earlier version of the same collection, but including only the years 2006-2018.)\",\n",
    "  \"created\": datetime.datetime.now().strftime(\"%Y-%m-%dT%H:%M:%SZ\"),    \n",
    "  \"publication_date\": \"2019-07-18\",\n",
    "  \"webpage\": \"https://we1s.ucsb.edu/research/we1s-materials/collections-topic-models/\",\n",
    "  \"licenses\": [\n",
    "    {\n",
    "      \"name\": \"BY-SA-4.0\",\n",
    "      \"path\": \"https://creativecommons.org/licenses/by-sa/4.0/legalcode\",\n",
    "      \"title\": \"Creative Commons Attribution-ShareAlike 4.0 International License\"\n",
    "    }\n",
    "  ],\n",
    "  \"notes\": \"This collection was produced with generous support from the Andrew W. Mellon Foundation.\"\n",
    "}\n"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Check IP Protection\n",
    "\n",
    "If your collection is based on restricted materials, run this cell to make sure there are no content fields."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Done!\n"
     ]
    }
   ],
   "source": [
    "import ujson\n",
    "bad_jsons = []\n",
    "content_fields = ['content', 'content-scrubbed', 'content-unscrubbed', 'content_scrubbed', 'content_unscrubbed', 'text']\n",
    "files = glob.glob(f'/home/jovyan/view/collections/{collection}/project_data/json/*.json')\n",
    "for file in files:\n",
    "    with open(file, 'r') as f:\n",
    "        doc = ujson.loads(f.read())\n",
    "    for field in content_fields:\n",
    "        if field in doc:\n",
    "            bad_jsons.append(file)\n",
    "if len(bad_jsons) > 0:\n",
    "    print('Some files contained content. View the bad_jsons list.')\n",
    "else:\n",
    "    print('Done!')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Insert DOI"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Done!\n"
     ]
    }
   ],
   "source": [
    "collection = '20200630_2323_reddit-humanities-2006-2019'\n",
    "doi_suffix = '4958695'\n",
    "collection_dir = f'/home/jovyan/view/collections/{collection}'\n",
    "files = ['index.html',\n",
    "#          'dfr-browser/topics25/data/info.json',\n",
    "         'dfr-browser/topics50/data/info.json',\n",
    "         'dfr-browser/topics100/data/info.json',\n",
    "         'dfr-browser/topics150/data/info.json',\n",
    "         'dfr-browser/topics200/data/info.json',\n",
    "         'dfr-browser/topics250/data/info.json'\n",
    "        ]\n",
    "\n",
    "import json\n",
    "for file in files:\n",
    "    filepath = f'{collection_dir}/{file}'\n",
    "    with open(filepath, 'r') as f:\n",
    "        doc = f.read()\n",
    "    doc = doc.replace('<li>MALLET data files: doi:[TBD]</li>\\n', '')\n",
    "    doc = doc.replace('zenodo.XXX', f'zenodo.{doi_suffix}')\n",
    "    with open(filepath, 'w') as f:\n",
    "        f.write(doc)\n",
    "print('Done!')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Export"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/project_data...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/diagnostics...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/assets...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/bin...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/data...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/fonts...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/img...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/js...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics100/lib...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/bin...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/data...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/fonts...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/img...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/js...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/dfr-browser/topics200/lib...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/diagnostics/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/diagnostics/js...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100/data...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100/img...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100/js...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics100/lib...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200/data...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200/img...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200/js...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/topic-bubbles/topics200/lib...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/assets/fontawesome...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/assets/fontawesome/css...\n",
      "Collecting resources from /home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities/assets/fontawesome/webfonts...\n",
      "Saving data package...\n",
      "Saving archive...\n",
      "Making temporary json folder...\n",
      "Zipping json folder...\n",
      "Creating .tar.gz...\n",
      "Removing zip archive...\n",
      "Restoring json folder...\n",
      "Archive saved to `/home/jovyan/view/collections/20200714_2157_reddit-students-and-the-humanities.tar.gz`.\n"
     ]
    }
   ],
   "source": [
    "# Usage\n",
    "export = ExportCollection(collection, options)\n",
    "export.package.descriptor\n",
    "export.infer_resources()\n",
    "# export.package.descriptor\n",
    "export.save(save_path)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "{'profile': 'data-package',\n",
       " 'name': '20190627_1756_us-proquest-minus-wsj',\n",
       " 'title': 'Collection 15: Articles mentioning “humanities” or “literature” from ProQuest’s Ethnic NewsWatch and GenderWatch',\n",
       " 'contributors': [{'title': 'WhatEvery1Says (WE1S) Project',\n",
       "   'path': 'https://we1s.ucsb.edu'}],\n",
       " 'description': \"A collection of word-frequency and other data representing 835 unique articles mentioning “humanities” or “literature” (no duplicate or close-variant documents) published mostly during 2016, 2018, and 2019 in 109 U.S. news sources gathered in ProQuest’s [Ethnic NewsWatch](https://www.proquest.com/products-services/ethnic_newswatch.html) (“ethnic and minority press”) and [GenderWatch](https://www.proquest.com/products-services/genderwatch.html) (sources gathered for “gender and women's studies, and gay, lesbian, bisexual, and transgender [GLBT] research”). WE1S and other researchers use this data to look for broad patterns and to help guide closer study.\",\n",
       " 'created': '2021-06-11T01:05:26Z',\n",
       " 'publication_date': '2019-06-27',\n",
       " 'webpage': 'https://we1s.ucsb.edu/research/we1s-materials/collections-topic-models/',\n",
       " 'licenses': [{'name': 'BY-SA-4.0',\n",
       "   'path': 'https://creativecommons.org/licenses/by-sa/4.0/legalcode',\n",
       "   'title': 'Creative Commons Attribution-ShareAlike 4.0 International License'}],\n",
       " 'notes': 'This collection was produced with generous support from the Andrew W. Mellon Foundation.',\n",
       " 'resources': [{'path': 'index.html',\n",
       "   'format': 'html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index-Copy1.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index2.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/img/loading.gif',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/css/style.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/dendrogram-topics100-index.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/dendrogram-topics10-index.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/dendrogram-topics25-index.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/dendrogram-topics50-index.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/dendrogram-topics75-index.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'project_data/json.zip',\n",
       "   'format': 'zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/Logo_Full.png', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/styles.css', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/scripts.js', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/jquery-3.4.1.slim.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/css/all.min.css', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.woff2',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.woff2',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.woff2',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index-Copy1.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/index2.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/img/loading.gif',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics10/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics25/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics50/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/img/loading.gif', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/utils.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics75/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/server', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/bin/prepare-data',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/index.css', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-theme.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/css/bootstrap-table.min.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/info.json', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/fonts/glyphicons-halflings-regular.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/img/loading.gif',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/dfb.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/js/extra.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/d3.min.js', 'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dfr-browser/topics100/lib/bootstrap-table.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/LICENSE', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/README.md', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/css/style.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics10/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics25/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics50/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/css/style.css', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics75/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/css/style.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/screenshot.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/img/we1s_logo.png',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3-legend.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.layout.cloud.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/d3.v5.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/dat.gui.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery-1.11.0.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jszip.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/polyfill.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/fetch.umd.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.css',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/lib/jquery.json-viewer.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/d3-mouse-event.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/script.js', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/utils.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/js/worker.min.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/config.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/tw.json', 'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/dt.json.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/info.json',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/topic_scaled.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'topic-bubbles/topics100/data/meta.csv.zip',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics25/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics50/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics100/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics10/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom-pub.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom.js', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index-title.html', 'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/pyldavis_custom-title.js',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'pyldavis/topics75/index-pub.html', 'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-cosine-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-average.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-complete.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-single.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-ward.html.gz',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics75-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics50-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics25-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics100-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-average.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-single.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-complete.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'dendrogram/partials/dendrogram-topics10-euclidean-ward.html',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/css/all.min.css', 'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.woff2',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-solid-900.svg',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.woff2',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.ttf',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-regular-400.eot',\n",
       "   'profile': 'data-resource'},\n",
       "  {'path': 'assets/fontawesome/webfonts/fa-brands-400.woff',\n",
       "   'profile': 'data-resource'},\n",
       "  ...]}"
      ]
     },
     "execution_count": 7,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "export.package.descriptor"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.6.8"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
